@@ -1,6 +1,5 @@
-import { config } from '@grafana/runtime';
+import { t } from '@grafana/i18n';
 import { SceneComponentProps, SceneObjectBase } from '@grafana/scenes';
-import { t } from 'app/core/internationalization';
 import { shareDashboardType } from 'app/features/dashboard/components/ShareModal/utils';
 import { SceneShareTabState, ShareView } from 'app/features/dashboard-scene/sharing/types';
 import { getDashboardSceneFor } from 'app/features/dashboard-scene/utils/utils';
@@ -12,9 +11,7 @@ export class CreateReportTab extends SceneObjectBase<SceneShareTabState> impleme
   static Component = CreateReportTabRenderer;
 
   public getTabLabel() {
-    return config.featureToggles.newDashboardSharingComponent
-      ? t('share-dashboard.menu.schedule-report-title', 'Schedule report')
-      : 'Report';
+    return t('share-dashboard.menu.schedule-report-title', 'Schedule report');
   }
 }
 
